@@ -306,8 +306,8 @@ class UserCatData(UserData):
         )
 
         data_ss = ds[key].sel(**subset_dict)
-        cplist = self._get_user_catparams(da=data_ss)
-        cglist = self._get_user_catgrids(da=data_ss)
+        cplist = self._get_user_catparams(key=key, da=data_ss)
+        cglist = self._get_user_catgrids(key=key, da=data_ss)
 
         param_dict = dict(zip([key], cplist))  # noqa B905
         grid_dict = dict(zip([key], cglist))  # noqa B905
@@ -324,19 +324,18 @@ class UserCatData(UserData):
             period=self.period,
         )
 
-    def _get_user_catgrids(self, da: xr.DataArray):
+    def _get_user_catgrids(self, key: str, da: xr.DataArray):
         """Get CatGrids from UserData."""
         cglist = []
-        for _var in self.var:
-            cg = CatGrids(
-                X_name=self.x_coord,
-                Y_name=self.y_coord,
-                proj=self.proj_ds,
-                resX=max(np.diff(da[self.x_coord].values)),
-                resY=max(np.diff(da[self.y_coord].values)),
-                toptobottom=_get_top_to_bottom(da, self.y_coord),
-            )
-            cglist.append(cg.dict())
+        cg = CatGrids(
+            X_name=self.x_coord,
+            Y_name=self.y_coord,
+            proj=self.proj_ds,
+            resX=max(np.diff(da[self.x_coord].values)),
+            resY=max(np.diff(da[self.y_coord].values)),
+            toptobottom=_get_top_to_bottom(da, self.y_coord),
+        )
+        cglist.append(cg.dict())
         return cglist
 
     def _get_ds_var_attrs(self, da: xr.DataArray, attr: str) -> str:
@@ -354,18 +353,17 @@ class UserCatData(UserData):
         except KeyError:
             return "None"
 
-    def _get_user_catparams(self, da: xr.DataArray):
+    def _get_user_catparams(self, key: str, da: xr.DataArray):
         """Get CatParams from UserData."""
         cplist = []
-        for _var in self.var:
-            cp = CatParams(
-                URL="",
-                varname=_var,
-                long_name=self._get_ds_var_attrs(da, "long_name"),
-                T_name=self.t_coord,
-                units=self._get_ds_var_attrs(da, "units"),
-            )
-            cplist.append(cp.dict())
+        cp = CatParams(
+            URL="",
+            varname=key,
+            long_name=self._get_ds_var_attrs(da, "long_name"),
+            T_name=self.t_coord,
+            units=self._get_ds_var_attrs(da, "units"),
+        )
+        cplist.append(cp.dict())
         return cplist
 
     def prep_wght_data(self) -> WeightData:
